% This program solves a simple uncoupled system
%    x' =  2*x,
%    y' = -3*y.

clear

%%% Set initial conditions:
x0 = -2;
y0 = 1;
tt = linspace(-5,5,1000);
xx = x0*exp( 2*tt);
yy = y0*exp(-3*tt);

%%% Draw the phase diagram and the solution
figure(1)
subplot(1,2,1)
hold off
[XX,YY] = meshgrid(linspace(-3,3,21));
quiver(XX,YY,2*XX,-3*YY,'k')
hold on
plot(xx,yy,'m',...
     x0,y0,'m.',...
    'LineWidth',2,'MarkerSize',30)
xlabel('x')
ylabel('y')
axis equal
axis([-3,3,-3,3])

%%% Draw the solution curves as functions of t:
subplot(1,2,2)
hold off
tt = linspace(-5,5,1000);
plot(tt,x0*exp( 2*tt),'r',...
     tt,y0*exp(-3*tt),'b',...
     0,x0,'r.',...
     0,y0,'b.',...
     [-5,5],[0,0],'k',...
     [0,0],[-3,3],'k','LineWidth',2,'MarkerSize',30)       
xlabel('t')
ylabel('x(t) and y(t)')
legend('x(t)','y(t)')
axis([-5,5,-3,3])
